/* meko
 * Copyright (C) 2001 Scott James Remnant <scott@netsplit.com>.
 * All Rights Reserved.
 *
 * chat_interface.h
 * -- 
 * $Id: chat_interface.h,v 1.3 2001/06/07 12:36:48 scott Exp $
 * 
 * This file is distributed according to the GNU General Public
 * License.  For full details, read the top of 'main.c' or the
 * file called COPYING that was distributed with this code.
 */

#ifndef _MEKO_CHAT_INTERFACE_H
#define _MEKO_CHAT_INTERFACE_H

/* Required includes */
#include <stdarg.h>
#include <time.h>
#include <gtk/gtk.h>
#include "say2_server.h"

/* Message types accepted by chat interfaces */
typedef enum {
	CHAT_MSGTYPE_MESSAGE  = 1 << 0,
	CHAT_MSGTYPE_USER     = 1 << 1,
	CHAT_MSGTYPE_SERVER   = 1 << 2,
	CHAT_MSGTYPE_SYSTEM   = 1 << 3,
	CHAT_MSGTYPE_OTHER    = 1 << 4
} ChatMsgType;

/* Recipient types accepted by chat interfaces */
typedef enum {
	CHAT_RECIPTYPE_NONE,
	CHAT_RECIPTYPE_ANY,
	CHAT_RECIPTYPE_USER,
	CHAT_RECIPTYPE_CHAN
} ChatRecipType;

/* structure describing the type of message we accept */
typedef struct _chat_accept ChatAccept;
struct _chat_accept {
	ChatMsgType    msg_type;
	ChatRecipType  recip_type;
	gchar         *recip;
};

/* Structure to hold pointers to the various widgets in a chat interface
 * that we care about
 */
typedef struct _chat_interface ChatInterface;
struct _chat_interface {
	/* Important Widgets */
	GtkWidget *top_vbox;
	GtkWidget *entry_box;
	GtkWidget *output_box;
	GtkWidget *nick_label;

	/* Window to change the title of, and the root of the new title */
	GtkWidget *title_win;
	gchar     *title_prefix;

	/* Server we are bound to */
	Say2Server *server;

	/* List of events we want to show */
	GSList *accept_list;
	
	/* Recipient of any messages typed into the entry box */
	ChatRecipType  recip_type;
	gchar         *recip;
};

/* Create and free ChatInterfaces */
ChatInterface *chat_interface_new(void);
void           chat_interface_free(ChatInterface *);

/* Output formatted information to a specific interface */
void chat_interface_sayto(ChatInterface *, const gchar *, ...);
void chat_interface_saytov(ChatInterface *, const gchar *, va_list);

/* Output formatted information to the right interface(s) */
void chat_interface_say(Say2Server *, const gchar *, ...);
void chat_interface_sayv(Say2Server *, const gchar *, va_list);
	        
/* Assign (or create) a Say2Server for the ChatInterface */
void chat_interface_set_server(ChatInterface *, Say2Server *);

/* Set the destination of text typed into the ChatInterface */
void chat_interface_set_destination(ChatInterface *, ChatRecipType,
		                    const gchar *);

/* Set the title window */
void chat_interface_set_title_win(ChatInterface *, GtkWidget *, const gchar *);

/* Update labels and text */
void chat_interface_update(ChatInterface *);
void chat_interface_update_by_server(Say2Server *);

#endif /* !_MEKO_CHAT_INTERFACE_H */
