/* meko
 * Copyright (C) 2001 Scott James Remnant <scott@netsplit.com>.
 * All Rights Reserved.
 *
 * connect_values.c
 *  - Connection information structure for the connection dialog
 * -- 
 * $Id: connect_values.c,v 1.2 2001/06/06 11:38:41 scott Exp $
 * 
 * This file is distributed according to the GNU General Public
 * License.  For full details, read the top of 'main.c' or the
 * file called COPYING that was distributed with this code.
 */

#include <glib.h>

#include <meko.h>

#include "connect_values.h"

#define DEFAULT_SERVER "localhost"
#define DEFAULT_PORT   "3797"
	
/* connect_values_new
 * Create a new ConnectValues structure
 */
ConnectValues *
connect_values_new(void)
{
	return g_new0(ConnectValues, 1);
}

/* connect_values_new_from
 * Create a new ConnectValues structure either by copying an existing one
 * or filling with sensible defaults
 */
ConnectValues *
connect_values_new_from(ConnectValues *orig_values)
{
	ConnectValues *cv;

	cv = connect_values_new();

	if (orig_values) {
		cv->server_name = g_strdup(orig_values->server_name);
		cv->server_port = g_strdup(orig_values->server_port);
		cv->nickname = g_strdup(orig_values->nickname);
		cv->password = g_strdup(orig_values->password);
		cv->email = g_strdup(orig_values->email);
		cv->tagline = g_strdup(orig_values->tagline);
	} else {
		cv->server_name = g_strdup(DEFAULT_SERVER);
		cv->server_port = g_strdup(DEFAULT_PORT);
		cv->nickname = g_strdup("");
		cv->password = g_strdup("");
		cv->email = g_strdup("");
		cv->tagline = g_strdup("");
	}

	return cv;
}

/* connect_values_free
 * Free up a ConnectValues structure
 */
void
connect_values_free(ConnectValues *cv)
{
	if (!cv)
		return;

	g_free(cv->server_name);
	g_free(cv->server_port);
	g_free(cv->nickname);
	g_free(cv->password);
	g_free(cv->email);
	g_free(cv->tagline);
	g_free(cv);
}
