/* meko
 * Copyright (C) 2001 Scott James Remnant <scott@netsplit.com>.
 * All Rights Reserved.
 *
 * main.c
 *  - Main window and main loop
 * -- 
 * $Id: main.c,v 1.6 2001/06/05 11:23:16 scott Exp $
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk/gtk.h>

#include <meko.h>

#include "chat_interface.h"

/* main_destroy
 * Called when the main window receives a destroy signal.  Leave gtk_main
 * and terminate the program
 */
static void
main_destroy(GtkWidget *widget, gpointer data)
{
	gtk_main_quit();
}

/* connect_clicked
 * Called then the Connect toolbar button is clicked.  Throws up a new
 * connect dialog.  If this is Ok'd it automatically closes the current
 * connection in that window.
 */
static void
connect_clicked(GtkWidget *widget, ChatInterface *ci)
{
	chat_interface_set_server(ci, GINT_TO_POINTER(1));
}

/* main
 * The main function, open a chat window and begin normal processing
 */
int
main(int argc, char *argv[])
{
	GtkWidget     *win, *top_vbox, *toolbar_frame, *toolbar_box, *button;
	ChatInterface *ci;

	/* Code to do colors in styles */
#if 0
	GdkColor  bg_color = { 0, 0, 0, 0 };
	GdkColor  fg_color = { 0, 0xffff, 0xffff, 0xffff };
	GtkStyle *style;

	gdk_colormap_alloc_color(gdk_colormap_get_system(), &bg_color,
			         FALSE, TRUE);
	gdk_colormap_alloc_color(gdk_colormap_get_system(), &fg_color,
			         FALSE, TRUE);

	style->base[GTK_STATE_NORMAL] = bg_color;
	style->bg[GTK_STATE_NORMAL] = bg_color;
	style->fg[GTK_STATE_NORMAL] = fg_color;
#endif

	/* Initialise GTK+ */
	gtk_set_locale();
	gtk_init(&argc, &argv);

	/* Create a new top level window */
	win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_wmclass(GTK_WINDOW(win), "chat", "Meko");
	gtk_window_set_title(GTK_WINDOW(win), "Meko " FULL_VERSION);
	gtk_window_set_policy(GTK_WINDOW(win), TRUE, TRUE, FALSE);
	gtk_widget_set_usize(win, 480, 320);
	gtk_signal_connect(GTK_OBJECT(win), "destroy",
			   GTK_SIGNAL_FUNC(main_destroy), NULL);

	/* Box for everything in the window */
	top_vbox = gtk_vbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(win), top_vbox);
	gtk_widget_show(top_vbox);

	/* Add a ChatInterface to it (FIXME: we don't free this yet) */
	ci = chat_interface_new();
	chat_interface_set_title_win(ci, win, "Meko " FULL_VERSION ": ");
	chat_interface_set_destination(ci, CHAT_RECIPTYPE_CHAN, 0);
	gtk_container_set_border_width(GTK_CONTAINER(ci->top_vbox), 4);
	gtk_box_pack_end(GTK_BOX(top_vbox), ci->top_vbox, TRUE, TRUE, 0);

	/* Toolbar frame */
	toolbar_frame = gtk_frame_new(NULL);
	gtk_frame_set_shadow_type(GTK_FRAME(toolbar_frame), GTK_SHADOW_OUT);
	gtk_box_pack_start(GTK_BOX(top_vbox), toolbar_frame,  FALSE, FALSE, 0);
	gtk_widget_show(toolbar_frame);

	/* Toolbar box */
	toolbar_box = gtk_hbutton_box_new();
	gtk_button_box_set_layout(GTK_BUTTON_BOX(toolbar_box),
				  GTK_BUTTONBOX_START);
	gtk_container_set_border_width(GTK_CONTAINER(toolbar_box), 2);
	gtk_container_add(GTK_CONTAINER(toolbar_frame), toolbar_box);
	gtk_widget_show(toolbar_box);

	/* Toolbar button */
	button = gtk_button_new_with_label("Connect");
	gtk_container_add(GTK_CONTAINER(toolbar_box), button);
	gtk_signal_connect(GTK_OBJECT(button), "clicked",
			   GTK_SIGNAL_FUNC(connect_clicked), (gpointer)ci);
	gtk_widget_show(button);

	/* Show the window */
	gtk_widget_show(win);
	gtk_widget_grab_focus(ci->entry_box);

	/* Throw up a connect dialog */
	chat_interface_set_server(ci, GINT_TO_POINTER(1));

	/* Let GTK handle our processing from here */
	gtk_main();
	
	return 0;
}
