/* meko
 * Copyright (C) 2001 Scott James Remnant <scott@netsplit.com>.
 * All Rights Reserved.
 *
 * say2_server.h
 * -- 
 * $Id: say2_server.h,v 1.3 2001/06/07 12:35:38 scott Exp $
 * 
 * This file is distributed according to the GNU General Public
 * License.  For full details, read the top of 'main.c' or the
 * file called COPYING that was distributed with this code.
 */

#ifndef _MEKO_SAY2_SERVER_H
#define _MEKO_SAY2_SERVER_H

/* Required includes */
#include <say2/say2.h>
#include "connect_values.h"

/* Status we can be on the server */
typedef enum {
	SAY2_STATUS_ACTIVE,
	SAY2_STATUS_BUSY,
	SAY2_STATUS_AWAY
} Say2Status;

/* Structure that holds information about a server connection */
typedef struct _say2_server Say2Server;
struct _say2_server {
	/* Socket to talk it on */
	Socket *sock;

	/* Reference count, number of chat interfaces using this */
	gint ref;

	/* Server name and port */
	gchar *server_name;
	gint   server_port;

	/* Information about ourselves */
	gchar *id;
	gchar *password;
	gchar *nickname;
	gchar *email;
	gchar *tagline;

	/* Our status */
	Say2Status  status;
	gchar      *status_msg;

	/* Squelch counters.  When these are 0 the responses aren't
	 * taken as anything special and can be sent to the user.  When > 0
	 * it means meko itself has requested something and doesn't want the
	 * user to see the response.
	 *
	 * This still isn't ideal, as it means that if the user does a command
	 * and meko does the same command before the user's reply comes back,
	 * the users will be squelched, not meko's
	 */
	gint squelch_prefs;
	gint squelch_members;
	gint squelch_whois;

	/* Should the members command send whois */
	gint members_do_whois;

	/* Are we in a history (frig with timestamps if they're old) */
	gboolean in_history;

	/* Captured whom information */
	gboolean in_whom;
	GSList  *whom_list;
	glong    whom_count;
	glong    whom_total;
};

/* Create and Free Say2Server structure */
Say2Server *say2_server_new(void);
void        say2_server_free(Say2Server *);

/* Connect to a say2 server */
void say2_server_connect(ConnectValues *, Say2Server *);

#endif /* !_MEKO_SAY2_SERVER_H */
